from mteb.abstasks.classification import AbsTaskClassification
from mteb.abstasks.task_metadata import TaskMetadata


class UkrFormalityClassification(AbsTaskClassification):
    metadata = TaskMetadata(
        name="UkrFormalityClassification",
        description="This dataset contains Ukrainian Formality Classification dataset obtained by trainslating English GYAFC data. English data source: https://aclanthology.org/N18-1012/ Translation into Ukrainian language using model: https://huggingface.co/facebook/nllb-200-distilled-600M Additionally, the dataset was balanced, with labels: 0 - informal, 1 - formal.",
        dataset={
            "path": "ukr-detect/ukr-formality-dataset-translated-gyafc",
            "revision": "671d1e6bbf45a74ef21af351fd4ef7b32b7856f8",
        },
        reference="https://huggingface.co/datasets/ukr-detect/ukr-formality-dataset-translated-gyafc",
        type="Classification",
        category="t2c",
        modalities=["text"],
        eval_splits=["train", "test"],
        eval_langs=["ukr-Cyrl"],
        main_score="accuracy",
        date=("2018-04-11", "2018-06-20"),
        domains=["News", "Written"],
        task_subtypes=["Topic classification"],
        license="openrail++",
        annotations_creators="derived",
        dialect=[],
        sample_creation="machine-translated",
        bibtex_citation=r"""
@inproceedings{rao-tetreault-2018-dear,
  author = {Rao, Sudha  and
Tetreault, Joel},
  booktitle = {Proceedings of the 2018 Conference of the North {A}merican Chapter of the Association for Computational Linguistics: Human Language Technologies, Volume 1 (Long Papers)},
  month = jun,
  publisher = {Association for Computational Linguistics},
  title = {Dear Sir or Madam, May {I} Introduce the {GYAFC} Dataset: Corpus, Benchmarks and Metrics for Formality Style Transfer},
  url = {https://aclanthology.org/N18-1012},
  year = {2018},
}
""",
        superseded_by="UkrFormalityClassification.v2",
    )

    def dataset_transform(
        self,
        num_proc: int | None = None,
    ):
        self.dataset = self.dataset.rename_column("labels", "label")
        self.dataset = self.dataset.class_encode_column("label")
        self.dataset = self.stratified_subsampling(
            self.dataset, seed=self.seed, splits=["train", "test"]
        )


class UkrFormalityClassificationV2(AbsTaskClassification):
    metadata = TaskMetadata(
        name="UkrFormalityClassification.v2",
        description="This dataset contains Ukrainian Formality Classification dataset obtained by trainslating English GYAFC data. English data source: https://aclanthology.org/N18-1012/ Translation into Ukrainian language using model: https://huggingface.co/facebook/nllb-200-distilled-600M Additionally, the dataset was balanced, with labels: 0 - informal, 1 - formal. This version corrects errors found in the original data. For details, see [pull request](https://github.com/embeddings-benchmark/mteb/pull/2900)",
        dataset={
            "path": "mteb/ukr_formality",
            "revision": "e0b2dfa57d505f207deb571e58b0bd0b81180bd4",
        },
        reference="https://huggingface.co/datasets/ukr-detect/ukr-formality-dataset-translated-gyafc",
        type="Classification",
        category="t2c",
        modalities=["text"],
        eval_splits=["test"],
        eval_langs=["ukr-Cyrl"],
        main_score="accuracy",
        date=("2018-04-11", "2018-06-20"),
        domains=["News", "Written"],
        task_subtypes=["Topic classification"],
        license="openrail++",
        annotations_creators="derived",
        dialect=[],
        sample_creation="machine-translated",
        bibtex_citation=r"""
@inproceedings{rao-tetreault-2018-dear,
  author = {Rao, Sudha  and
Tetreault, Joel},
  booktitle = {Proceedings of the 2018 Conference of the North {A}merican Chapter of the Association for Computational Linguistics: Human Language Technologies, Volume 1 (Long Papers)},
  month = jun,
  publisher = {Association for Computational Linguistics},
  title = {Dear Sir or Madam, May {I} Introduce the {GYAFC} Dataset: Corpus, Benchmarks and Metrics for Formality Style Transfer},
  url = {https://aclanthology.org/N18-1012},
  year = {2018},
}
""",
        adapted_from=["UkrFormalityClassification"],
    )

    def dataset_transform(
        self,
        num_proc: int | None = None,
    ):
        self.dataset = self.stratified_subsampling(
            self.dataset, seed=self.seed, splits=["train", "test"]
        )



from mteb.abstasks.retrieval import AbsTaskRetrieval
from mteb.abstasks.task_metadata import TaskMetadata


class VisRAGRetChartQA(AbsTaskRetrieval):
    """VisRAG Retrieval task for ChartQA charts.

    The corpus contains chart images and the queries are multiple‑choice questions
    about those charts.  Each query is linked to one relevant chart image.
    """

    metadata = TaskMetadata(
        name="VisRAGRetChartQA",
        description="Assess end-to-end vision-based RAG performance on real-world charts requiring complex logical and visual reasoning from retrieved images.",
        reference="https://arxiv.org/abs/2203.10244",
        type="Retrieval",
        task_subtypes=["Image Text Retrieval"],
        category="t2i",
        modalities=["text", "image"],
        eval_splits=["train"],
        eval_langs=["eng-Latn"],
        main_score="recall_at_10",
        dataset={
            "path": "mteb/VisRAGRetChartQA",
            "revision": "4665d4a3ebc9ea5a4e635985a4fd2a595b78b3c0",
        },
        date=("2010-01-01", "2021-12-31"),
        domains=["Web", "Non-fiction"],
        license="gpl-3.0",
        annotations_creators="derived",
        dialect=[],
        sample_creation="found",
        bibtex_citation="""@misc{masry2022chartqabenchmarkquestionanswering,
  archiveprefix = {arXiv},
  author = {Ahmed Masry and Do Xuan Long and Jia Qing Tan and Shafiq Joty and Enamul Hoque},
  eprint = {2203.10244},
  primaryclass = {cs.CL},
  title = {ChartQA: A Benchmark for Question Answering about Charts with Visual and Logical Reasoning},
  url = {https://arxiv.org/abs/2203.10244},
  year = {2022},
}""",
    )



from mteb.abstasks import AbsTaskClassification
from mteb.abstasks.task_metadata import TaskMetadata


class MNISTClassification(AbsTaskClassification):
    input_column_name: str = "image"
    samples_per_label: int = 16
    n_experiments: int = 5

    metadata = TaskMetadata(
        name="MNIST",
        description="Classifying handwritten digits.",
        reference="https://en.wikipedia.org/wiki/MNIST_database",
        dataset={
            "path": "mteb/mnist",
            "revision": "cf6afcbae72cc3bb1fc07a9480fe0d8e0b615fcd",
        },
        type="ImageClassification",
        category="i2c",
        eval_splits=["test"],
        eval_langs=["eng-Latn"],
        main_score="accuracy",
        date=(
            "2010-01-01",
            "2010-04-01",
        ),  # Estimated range for the collection of reviews
        domains=["Encyclopaedic"],
        task_subtypes=["Object recognition"],
        license="not specified",
        annotations_creators="derived",
        dialect=[],
        modalities=["image"],
        sample_creation="created",
        bibtex_citation=r"""
@article{lecun2010mnist,
  author = {LeCun, Yann and Cortes, Corinna and Burges, CJ},
  journal = {ATT Labs [Online]. Available: http://yann.lecun.com/exdb/mnist},
  title = {MNIST handwritten digit database},
  volume = {2},
  year = {2010},
}
""",
    )



from mteb.abstasks.classification import AbsTaskClassification
from mteb.abstasks.task_metadata import TaskMetadata


class RuSciBenchCoreRiscClassification(AbsTaskClassification):
    metadata = TaskMetadata(
        name="RuSciBenchCoreRiscClassification",
        dataset={
            "path": "mlsa-iai-msu-lab/ru_sci_bench_mteb",
            "revision": "fbc0599a0b5f00b3c7d87ab4d13490f04fb77f8e",
        },
        description="This binary classification task aims to determine whether a scientific paper (based on its title and abstract) belongs to the Core of the Russian Science Citation Index (RISC). The RISC includes a wide range of publications, but the Core RISC comprises the most cited and prestigious journals, dissertations, theses, monographs, and studies. The task is provided for both Russian and English versions of the paper's title and abstract.",
        reference="https://github.com/mlsa-iai-msu-lab/ru_sci_bench_mteb",
        type="Classification",
        category="t2c",
        modalities=["text"],
        eval_splits=["test"],
        eval_langs={
            "corerisc_ru": ["rus-Cyrl"],
            "corerisc_en": ["eng-Latn"],
        },
        main_score="accuracy",
        date=("2007-01-01", "2023-01-01"),
        domains=["Academic", "Non-fiction", "Written"],
        task_subtypes=[],
        license="mit",
        annotations_creators="derived",
        dialect=[],
        sample_creation="found",
        bibtex_citation=r"""
@article{vatolin2024ruscibench,
  author = {Vatolin, A. and Gerasimenko, N. and Ianina, A. and Vorontsov, K.},
  doi = {10.1134/S1064562424602191},
  issn = {1531-8362},
  journal = {Doklady Mathematics},
  month = {12},
  number = {1},
  pages = {S251--S260},
  title = {RuSciBench: Open Benchmark for Russian and English Scientific Document Representations},
  url = {https://doi.org/10.1134/S1064562424602191},
  volume = {110},
  year = {2024},
}
""",
        prompt="Classify whether a scientific article is part of the core RISC or not based on the title and abstract",
    )


class RuSciBenchPubTypeClassification(AbsTaskClassification):
    metadata = TaskMetadata(
        name="RuSciBenchPubTypeClassification",
        dataset={
            "path": "mlsa-iai-msu-lab/ru_sci_bench_mteb",
            "revision": "fbc0599a0b5f00b3c7d87ab4d13490f04fb77f8e",
        },
        description="This task involves classifying scientific papers (based on their title and abstract) into different publication types. The dataset identifies the following types: 'Article', 'Conference proceedings', 'Survey', 'Miscellanea', 'Short message', 'Review', and 'Personalia'. This task is available for both Russian and English versions of the paper's title and abstract.",
        reference="https://github.com/mlsa-iai-msu-lab/ru_sci_bench_mteb",
        type="Classification",
        category="t2c",
        modalities=["text"],
        eval_splits=["test"],
        eval_langs={
            "pub_type_ru": ["rus-Cyrl"],
            "pub_type_en": ["eng-Latn"],
        },
        main_score="accuracy",
        date=("2007-01-01", "2023-01-01"),
        domains=["Academic", "Non-fiction", "Written"],
        task_subtypes=[],
        license="mit",
        annotations_creators="derived",
        dialect=[],
        sample_creation="found",
        bibtex_citation=r"""
@article{vatolin2024ruscibench,
  author = {Vatolin, A. and Gerasimenko, N. and Ianina, A. and Vorontsov, K.},
  doi = {10.1134/S1064562424602191},
  issn = {1531-8362},
  journal = {Doklady Mathematics},
  month = {12},
  number = {1},
  pages = {S251--S260},
  title = {RuSciBench: Open Benchmark for Russian and English Scientific Document Representations},
  url = {https://doi.org/10.1134/S1064562424602191},
  volume = {110},
  year = {2024},
}
""",
        prompt="Classify the type of scientific paper based on the title and abstract",
    )


class RuSciBenchGRNTIClassificationV2(AbsTaskClassification):
    metadata = TaskMetadata(
        name="RuSciBenchGRNTIClassification.v2",
        dataset={
            "path": "mlsa-iai-msu-lab/ru_sci_bench_mteb",
            "revision": "fbc0599a0b5f00b3c7d87ab4d13490f04fb77f8e",
        },
        description="Classification of scientific papers based on the GRNTI (State Rubricator of Scientific and Technical Information) rubricator. GRNTI is a universal hierarchical classification of knowledge domains adopted in Russia and CIS countries to systematize the entire flow of scientific and technical information. This task uses the first level of the GRNTI hierarchy and top 28 classes by frequency. In this version, English language support has been added and data partitioning has been slightly modified.",
        reference="https://github.com/mlsa-iai-msu-lab/ru_sci_bench_mteb",
        type="Classification",
        category="t2c",
        modalities=["text"],
        eval_splits=["test"],
        eval_langs={
            "grnti_ru": ["rus-Cyrl"],
            "grnti_en": ["eng-Latn"],
        },
        main_score="accuracy",
        date=("2007-01-01", "2023-01-01"),
        domains=["Academic", "Non-fiction", "Written"],
        task_subtypes=[],
        license="mit",
        annotations_creators="derived",
        dialect=[],
        sample_creation="found",
        bibtex_citation=r"""
@article{vatolin2024ruscibench,
  author = {Vatolin, A. and Gerasimenko, N. and Ianina, A. and Vorontsov, K.},
  doi = {10.1134/S1064562424602191},
  issn = {1531-8362},
  journal = {Doklady Mathematics},
  month = {12},
  number = {1},
  pages = {S251--S260},
  title = {RuSciBench: Open Benchmark for Russian and English Scientific Document Representations},
  url = {https://doi.org/10.1134/S1064562424602191},
  volume = {110},
  year = {2024},
}
""",
        prompt="Classify the category of scientific papers based on the titles and abstracts",
    )


class RuSciBenchOECDClassificationV2(AbsTaskClassification):
    metadata = TaskMetadata(
        name="RuSciBenchOECDClassification.v2",
        dataset={
            "path": "mlsa-iai-msu-lab/ru_sci_bench_mteb",
            "revision": "fbc0599a0b5f00b3c7d87ab4d13490f04fb77f8e",
        },
        description="Classification of scientific papers based on the OECD (Organization for Economic Co-operation and Development) rubricator. OECD provides a hierarchical 3-level system of classes for labeling scientific articles. This task uses the first two levels of the OECD hierarchy, top 29 classes. In this version, English language support has been added and data partitioning has been slightly modified.",
        reference="https://github.com/mlsa-iai-msu-lab/ru_sci_bench_mteb",
        type="Classification",
        category="t2c",
        modalities=["text"],
        eval_splits=["test"],
        eval_langs={
            "oecd_ru": ["rus-Cyrl"],
            "oecd_en": ["eng-Latn"],
        },
        main_score="accuracy",
        date=("2007-01-01", "2023-01-01"),
        domains=["Academic", "Non-fiction", "Written"],
        task_subtypes=[],
        license="mit",
        annotations_creators="derived",
        dialect=[],
        sample_creation="found",
        bibtex_citation=r"""
@article{vatolin2024ruscibench,
  author = {Vatolin, A. and Gerasimenko, N. and Ianina, A. and Vorontsov, K.},
  doi = {10.1134/S1064562424602191},
  issn = {1531-8362},
  journal = {Doklady Mathematics},
  month = {12},
  number = {1},
  pages = {S251--S260},
  title = {RuSciBench: Open Benchmark for Russian and English Scientific Document Representations},
  url = {https://doi.org/10.1134/S1064562424602191},
  volume = {110},
  year = {2024},
}
""",
        prompt="Classify the category of scientific papers based on the titles and abstracts",
    )



from mteb.abstasks.classification import AbsTaskClassification
from mteb.abstasks.task_metadata import TaskMetadata


class BirdCLEFClassification(AbsTaskClassification):
    metadata = TaskMetadata(
        name="BirdCLEF",
        description="BirdCLEF+ 2025 dataset for species identification from audio, focused on birds, amphibians, mammals and insects from the Middle Magdalena Valley of Colombia. Downsampled to 50 classes with 20 samples each.",
        reference="https://huggingface.co/datasets/christopher/birdclef-2025",
        dataset={
            "path": "mteb/birdclef25-mini",
            "revision": "582215665b247604b555da7ff4e071f82d3617db",
        },
        type="AudioClassification",
        category="a2c",
        eval_splits=["train"],
        eval_langs=["zxx-Zxxx"],
        main_score="accuracy",
        date=("2025-01-01", "2025-12-31"),  # Competition year
        domains=["Spoken", "Speech", "Bioacoustics"],
        task_subtypes=["Species Classification"],
        license="cc-by-nc-4.0",
        annotations_creators="expert-annotated",
        dialect=[],
        modalities=["audio"],
        sample_creation="found",
        bibtex_citation=r"""
@dataset{birdclef2025,
  author = {Christopher},
  publisher = {Hugging Face},
  title = {BirdCLEF+ 2025},
  url = {https://huggingface.co/datasets/christopher/birdclef-2025},
  year = {2025},
}
""",
    )

    input_column_name: str = "recording"
    label_column_name: str = "primary_label"

    is_cross_validation: bool = True



from mteb.abstasks.retrieval import AbsTaskRetrieval
from mteb.abstasks.task_metadata import TaskMetadata


class VisRAGRetPlotQA(AbsTaskRetrieval):
    """VisRAG Retrieval task for PlotQA scientific plots.

    The corpus contains scientific plot images and the queries are questions
    requiring reasoning over the plots.  Each query has exactly one relevant
    plot image.
    """

    metadata = TaskMetadata(
        name="VisRAGRetPlotQA",
        description="Execute vision-based retrieval and numerical reasoning over scientific plots to answer questions without relying on structured data parsing.",
        reference="https://arxiv.org/abs/1909.00997",
        type="Retrieval",
        task_subtypes=["Image Text Retrieval"],
        category="t2i",
        modalities=["text", "image"],
        eval_splits=["train"],
        eval_langs=["eng-Latn"],
        main_score="recall_at_10",
        dataset={
            "path": "mteb/VisRAGRetPlotQA",
            "revision": "0c2dad65a167e80a131c4839211ca8ec5b7f870e",
        },
        date=("2000-01-01", "2019-12-31"),
        domains=["Web", "Non-fiction"],
        license="mit",
        annotations_creators="derived",
        dialect=[],
        sample_creation="found",
        bibtex_citation="""@misc{methani2020plotqareasoningscientificplots,
  archiveprefix = {arXiv},
  author = {Nitesh Methani and Pritha Ganguly and Mitesh M. Khapra and Pratyush Kumar},
  eprint = {1909.00997},
  primaryclass = {cs.CV},
  title = {PlotQA: Reasoning over Scientific Plots},
  url = {https://arxiv.org/abs/1909.00997},
  year = {2020},
}""",
    )



from mteb.abstasks.clustering import AbsTaskClustering, _convert_to_fast
from mteb.abstasks.clustering_legacy import AbsTaskClusteringLegacy
from mteb.abstasks.task_metadata import TaskMetadata

NUM_SAMPLES = 2048


class BlurbsClusteringP2P(AbsTaskClusteringLegacy):
    metadata = TaskMetadata(
        name="BlurbsClusteringP2P",
        description="Clustering of book titles+blurbs. Clustering of 28 sets, either on the main or secondary genre.",
        reference="https://www.inf.uni-hamburg.de/en/inst/ab/lt/resources/data/germeval-2019-hmc.html",
        dataset={
            "path": "slvnwhrl/blurbs-clustering-p2p",
            "revision": "a2dd5b02a77de3466a3eaa98ae586b5610314496",
        },
        type="Clustering",
        category="t2c",
        modalities=["text"],
        eval_splits=["test"],
        eval_langs=["deu-Latn"],
        main_score="v_measure",
        date=("1900-01-01", "2019-12-31"),
        domains=["Fiction", "Written"],
        task_subtypes=["Thematic clustering"],
        license="cc-by-nc-4.0",
        annotations_creators="derived",
        dialect=[],
        sample_creation="found",
        bibtex_citation=r"""
@inproceedings{Remus2019GermEval2T,
  author = {Steffen Remus and Rami Aly and Chris Biemann},
  booktitle = {Conference on Natural Language Processing},
  title = {GermEval 2019 Task 1: Hierarchical Classification of Blurbs},
  url = {https://api.semanticscholar.org/CorpusID:208334484},
  year = {2019},
}
""",
        superseded_by="BlurbsClusteringP2P.v2",
    )


class BlurbsClusteringP2PFast(AbsTaskClustering):
    # a faster version of BlurbsClusteringP2P, since it does not sample from the same distribution we can't use the AbsTaskClustering, instead we
    # simply downsample each cluster.
    max_document_to_embed = NUM_SAMPLES
    max_fraction_of_documents_to_embed = None

    metadata = TaskMetadata(
        name="BlurbsClusteringP2P.v2",
        description="Clustering of book titles+blurbs. Clustering of 28 sets, either on the main or secondary genre.",
        reference="https://www.inf.uni-hamburg.de/en/inst/ab/lt/resources/data/germeval-2019-hmc.html",
        dataset={
            "path": "slvnwhrl/blurbs-clustering-p2p",
            "revision": "a2dd5b02a77de3466a3eaa98ae586b5610314496",
        },
        type="Clustering",
        category="t2c",
        modalities=["text"],
        eval_splits=["test"],
        eval_langs=["deu-Latn"],
        main_score="v_measure",
        date=(
            "1900-01-01",
            "2019-12-31",
        ),  # since it is books it is likely to be from the 20th century -> paper from 2019
        domains=["Fiction", "Written"],
        task_subtypes=["Thematic clustering"],
        license="cc-by-nc-4.0",
        annotations_creators="derived",
        dialect=[],
        sample_creation="found",
        bibtex_citation=r"""
@inproceedings{Remus2019GermEval2T,
  author = {Steffen Remus and Rami Aly and Chris Biemann},
  booktitle = {Conference on Natural Language Processing},
  title = {GermEval 2019 Task 1: Hierarchical Classification of Blurbs},
  url = {https://api.semanticscholar.org/CorpusID:208334484},
  year = {2019},
}
""",
        adapted_from=["BlurbsClusteringP2P"],
    )

    def dataset_transform(
        self,
        num_proc: int | None = None,
    ):
        self.dataset = _convert_to_fast(
            self.dataset, self.input_column_name, self.label_column_name, self.seed
        )



from .esc50_clustering import ESC50Clustering
from .gtzan_genre_clustering import GTZANGenreClustering
from .music_genre import MusicGenreClustering
from .vehicle_sound_clustering import VehicleSoundClustering

__all__ = [
    "ESC50Clustering",
    "GTZANGenreClustering",
    "MusicGenreClustering",
    "VehicleSoundClustering",
]



from __future__ import annotations

import logging
from typing import TYPE_CHECKING, Any, TypedDict

import numpy as np
from sklearn.metrics.pairwise import (
    paired_cosine_distances,
    paired_euclidean_distances,
    paired_manhattan_distances,
)

from mteb._create_dataloaders import _create_dataloader_from_texts, create_dataloader
from mteb._evaluators.evaluator import Evaluator
from mteb.similarity_functions import compute_pairwise_similarity

if TYPE_CHECKING:
    from datasets import Dataset
    from numpy.typing import NDArray

    from mteb.abstasks.task_metadata import TaskMetadata
    from mteb.models import EncoderProtocol
    from mteb.types import EncodeKwargs, PromptType

logger = logging.getLogger(__name__)


class PairClassificationDistances(TypedDict):
    """Pair classification distances.

    Attributes:
        cosine_scores: Cosine similarity scores.
        euclidean_distances: Euclidean similarity scores.
        manhattan_distances: Manhattan similarity scores.
        similarity_scores: Similarity scores.
        dot_scores: Dot similarity scores.
    """

    cosine_scores: list[float]
    euclidean_distances: list[float]
    manhattan_distances: list[float]
    similarity_scores: list[float]
    dot_scores: list[float]


class PairClassificationEvaluator(Evaluator):
    """Evaluate a model based on the similarity of the embeddings by calculating the accuracy of identifying similar and dissimilar sentences.

    The metrics are the cosine similarity as well as euclidean and Manhattan distance
    The returned score is the accuracy with a specified metric.
    The results are written in a CSV. If a CSV already exists, then values are appended.
    The labels need to be 0 for dissimilar pairs and 1 for similar pairs.

    Args:
        dataset: Dataset to evaluate.
        input1_column_name: The first column of sentences
        input2_column_name: The second column of sentences
        labels: labels[i] is the label for the pair (sentences1[i], sentences2[i]). Must be 0 or 1
        batch_size: Batch size used to compute embeddings
    """

    def __init__(
        self,
        dataset: Dataset,
        input1_column_name: str,
        input2_column_name: str,
        task_metadata: TaskMetadata,
        hf_split: str,
        hf_subset: str,
        input1_prompt_type: PromptType | None,
        input2_prompt_type: PromptType | None,
        **kwargs,
    ) -> None:
        super().__init__(**kwargs)
        self.dataset = dataset
        self.input1_column_name = input1_column_name
        self.input2_column_name = input2_column_name
        self.task_metadata = task_metadata
        self.hf_split = hf_split
        self.hf_subset = hf_subset
        self.input1_prompt_type = input1_prompt_type
        self.input2_prompt_type = input2_prompt_type

        if len(self.dataset[self.input1_column_name]) != len(
            self.dataset[self.input2_column_name]
        ):
            raise ValueError(
                f"First and second input columns must have the same length for task {task_metadata.name}"
            )

    def __call__(
        self,
        model: EncoderProtocol,
        encode_kwargs: EncodeKwargs,
        num_proc: int | None = None,
    ) -> PairClassificationDistances:
        logger.info("Running pair classification - Encoding samples (1/2)")
        embeddings1 = model.encode(
            create_dataloader(
                self.dataset.select_columns(self.input1_column_name),
                task_metadata=self.task_metadata,
                input_column=self.input1_column_name,
                num_proc=num_proc,
                **encode_kwargs,
            ),
            task_metadata=self.task_metadata,
            hf_split=self.hf_split,
            hf_subset=self.hf_subset,
            prompt_type=self.input1_prompt_type,
            **encode_kwargs,
        )
        logger.info("Running pair classification - Encoding samples (2/2)")
        embeddings2 = model.encode(
            create_dataloader(
                self.dataset.select_columns(self.input2_column_name),
                task_metadata=self.task_metadata,
                input_column=self.input2_column_name,
                num_proc=num_proc,
                **encode_kwargs,
            ),
            task_metadata=self.task_metadata,
            hf_split=self.hf_split,
            hf_subset=self.hf_subset,
            prompt_type=self.input2_prompt_type,
            **encode_kwargs,
        )

        logger.info("Running pair classification - Evaluating pair similarity...")
        cosine_scores = 1 - paired_cosine_distances(embeddings1, embeddings2)
        manhattan_distances = paired_manhattan_distances(embeddings1, embeddings2)
        euclidean_distances = paired_euclidean_distances(embeddings1, embeddings2)

        similarity_scores = compute_pairwise_similarity(model, embeddings1, embeddings2)

        embeddings1_np = np.asarray(embeddings1)
        embeddings2_np = np.asarray(embeddings2)
        dot_scores = np.asarray(
            [
                np.dot(embeddings1_np[i], embeddings2_np[i])
                for i in range(len(embeddings1_np))
            ]
        )
        return PairClassificationDistances(
            cosine_scores=cosine_scores.tolist(),
            euclidean_distances=euclidean_distances.tolist(),
            manhattan_distances=manhattan_distances.tolist(),
            similarity_scores=similarity_scores.tolist(),
            dot_scores=dot_scores.tolist(),
        )

    @staticmethod
    def _encode_unique_texts(
        all_texts: list[str],
        model: EncoderProtocol,
        task_metadata: TaskMetadata,
        hf_split: str,
        hf_subset: str,
        **encode_kwargs: Any,
    ) -> NDArray[np.floating]:
        index_map = {}
        all_unique_texts: list[str] = []
        all_texts_indexes = []
        for text in all_texts:
            text_hash = hash(text)
            if text_hash not in index_map:
                index_map[text_hash] = len(all_unique_texts)
                all_unique_texts.append(text)
            all_texts_indexes.append(index_map[text_hash])
        logger.warning(
            f"A total on {len(all_texts) - len(all_unique_texts)}/{len(all_texts)} duplicate texts were found during encoding. Only encoding unique text and duplicating embeddings across."
        )
        all_unique_texts_embs = np.asarray(
            model.encode(
                _create_dataloader_from_texts(all_unique_texts, **encode_kwargs),
                task_metadata=task_metadata,
                hf_split=hf_split,
                hf_subset=hf_subset,
                **encode_kwargs,
            )
        )
        return all_unique_texts_embs[all_texts_indexes]



from mteb.abstasks.classification import AbsTaskClassification
from mteb.abstasks.task_metadata import TaskMetadata


class SwissJudgementClassification(AbsTaskClassification):
    metadata = TaskMetadata(
        name="SwissJudgementClassification",
        description="Multilingual, diachronic dataset of Swiss Federal Supreme Court cases annotated with the respective binarized judgment outcome (approval/dismissal)",
        reference="https://aclanthology.org/2021.nllp-1.3/",
        dataset={
            "path": "mteb/SwissJudgementClassification",
            "revision": "2541705ce837c495e85aa3c44b41a92fa4bd12a8",
        },
        type="Classification",
        category="t2c",
        modalities=["text"],
        eval_splits=["test"],
        eval_langs={
            "de": ["deu-Latn"],
            "fr": ["fra-Latn"],
            "it": ["ita-Latn"],
        },
        main_score="accuracy",
        date=("2020-12-15", "2022-04-08"),
        domains=["Legal", "Written"],
        task_subtypes=[
            "Political classification",
        ],
        license="cc-by-4.0",
        annotations_creators="expert-annotated",
        dialect=[],
        sample_creation="found",
        bibtex_citation=r"""
@misc{niklaus2022empirical,
  archiveprefix = {arXiv},
  author = {Joel Niklaus and Matthias Stürmer and Ilias Chalkidis},
  eprint = {2209.12325},
  primaryclass = {cs.CL},
  title = {An Empirical Study on Cross-X Transfer for Legal Judgment Prediction},
  year = {2022},
}
""",
    )



from mteb.abstasks.classification import AbsTaskClassification
from mteb.abstasks.task_metadata import TaskMetadata


class VocalSoundClassification(AbsTaskClassification):
    metadata = TaskMetadata(
        name="VocalSound",
        description="Human Vocal Sound Classification Dataset.",
        reference="https://huggingface.co/datasets/lmms-lab/vocalsound",
        dataset={
            "path": "mteb/vocalsound",
            "revision": "426c4f4779901e731f0ba7157de727750325a68b",
        },
        type="AudioClassification",
        category="a2c",
        eval_splits=["test"],
        eval_langs=["eng-Latn"],
        main_score="accuracy",
        date=("2022-01-01", "2023-01-01"),
        domains=["Spoken"],
        task_subtypes=["Vocal Sound Classification"],
        license="cc-by-sa-4.0",
        annotations_creators="human-annotated",
        dialect=[],
        modalities=["audio"],
        sample_creation="found",
        bibtex_citation=r"""
@inproceedings{Gong_2022,
  author = {Gong, Yuan and Yu, Jin and Glass, James},
  booktitle = {ICASSP 2022 - 2022 IEEE International Conference on Acoustics, Speech and Signal Processing (ICASSP)},
  doi = {10.1109/icassp43922.2022.9746828},
  month = may,
  publisher = {IEEE},
  title = {Vocalsound: A Dataset for Improving Human Vocal Sounds Recognition},
  url = {http://dx.doi.org/10.1109/ICASSP43922.2022.9746828},
  year = {2022},
}
""",
    )

    input_column_name: str = "audio"
    label_column_name: str = "answer"

    def dataset_transform(self):
        self.dataset["train"] = self.dataset["val"]



from .ask_ubuntu_dup_questions_vn import AskUbuntuDupQuestionsVN
from .sci_docs_reranking_vn import SciDocsRerankingVN
from .stack_overflow_dup_questions_vn import StackOverflowDupQuestionsVN

__all__ = [
    "AskUbuntuDupQuestionsVN",
    "SciDocsRerankingVN",
    "StackOverflowDupQuestionsVN",
]



from __future__ import annotations

import logging
from typing import TYPE_CHECKING

import torch
from datasets import Dataset
from tqdm.auto import tqdm

from mteb._create_dataloaders import _create_dataloader_from_texts
from mteb._evaluators.evaluator import Evaluator

if TYPE_CHECKING:
    from mteb.abstasks.task_metadata import TaskMetadata
    from mteb.models import EncoderProtocol
    from mteb.types import Array, EncodeKwargs

logger = logging.getLogger(__name__)


class BitextMiningEvaluator(Evaluator):
    def __init__(
        self,
        sentences: Dataset,
        task_metadata: TaskMetadata,
        hf_split: str,
        hf_subset: str,
        pair_columns: list[tuple[str, str]],
        **kwargs,
    ) -> None:
        super().__init__(**kwargs)
        self.pairs = pair_columns
        self.n = len(sentences)
        self.sentences = sentences
        self.hf_split = hf_split
        self.hf_subset = hf_subset
        self.task_metadata = task_metadata

    def __call__(
        self,
        model: EncoderProtocol,
        *,
        encode_kwargs: EncodeKwargs,
        num_proc: int | None = None,
    ) -> dict[str, list[dict[str, float]]]:
        pair_elements = {p for pair in self.pairs for p in pair}
        if isinstance(self.sentences, Dataset):
            subsets = [
                col for col in self.sentences.features.keys() if col in pair_elements
            ]
        else:
            # BUCC outputs a dict instead of a Dataset
            subsets = list(pair_elements)

        embeddings = {}
        for sub in tqdm(subsets):
            dataloader = _create_dataloader_from_texts(
                self.sentences[sub],
                num_proc=num_proc,
                **encode_kwargs,
            )
            embeddings[sub] = model.encode(
                dataloader,
                task_metadata=self.task_metadata,
                # parallel datasets have lang pairs for subset
                hf_subset=self.hf_subset if self.hf_subset != "parallel" else sub,
                hf_split=self.hf_split,
                **encode_kwargs,
            )

        logger.info("Finding nearest neighbors...")
        neighbours = {}
        for i, (key1, key2) in enumerate(tqdm(self.pairs, desc="Matching sentences")):
            neighbours[f"{key1}-{key2}"] = self._similarity_search(
                embeddings[key1], embeddings[key2], model
            )
        return neighbours

    def _similarity_search(
        self,
        query_embeddings: Array,
        corpus_embeddings: Array,
        model: EncoderProtocol,
        query_chunk_size: int = 100,
        corpus_chunk_size: int = 500_000,
    ) -> list[dict[str, float]]:
        """This function performs a cosine similarity search between a list of query embeddings and a list of corpus embeddings.

        It can be used for Information Retrieval / Semantic Search for corpora up to about 1 Million entries.

        Args:
            query_embeddings: A 2 dimensional tensor with the query embeddings.
            corpus_embeddings: A 2 dimensional tensor with the corpus embeddings.
            model: The model used to encode the queries and corpus. This is used to check if the embeddings are on the same device and to encode the
                queries and corpus if they are not already tensors.
            query_chunk_size: Process 100 queries simultaneously. Increasing that value increases the speed, but requires more memory.
            corpus_chunk_size: Scans the corpus 100k entries at a time. Increasing that value increases the speed, but requires more memory.

        Returns:
            Returns a list with one entry for each query. Each entry is a list of dictionaries with the keys 'corpus_id' and 'score', sorted by
                decreasing cosine similarity scores.
        """
        if len(query_embeddings.shape) == 1:
            query_embeddings = query_embeddings.reshape(1, *query_embeddings.shape)
        if len(corpus_embeddings.shape) == 1:
            corpus_embeddings = corpus_embeddings.reshape(1, *corpus_embeddings)

        # Check that corpus and queries are on the same device
        if (
            isinstance(corpus_embeddings, torch.Tensor)
            and isinstance(query_embeddings, torch.Tensor)
            and corpus_embeddings.device != query_embeddings.device
        ):
            query_embeddings = query_embeddings.to(corpus_embeddings.device)

        queries_result_list: list[list[dict[str, float]]] = [
            [] for _ in range(len(query_embeddings))
        ]

        for query_start_idx in range(0, len(query_embeddings), query_chunk_size):
            # Iterate over chunks of the corpus
            for corpus_start_idx in range(0, len(corpus_embeddings), corpus_chunk_size):
                # Compute cosine similarities
                similarity_scores = model.similarity(
                    query_embeddings[
                        query_start_idx : query_start_idx + query_chunk_size
                    ],
                    corpus_embeddings[
                        corpus_start_idx : corpus_start_idx + corpus_chunk_size
                    ],
                )

                # Get top-k scores
                cos_scores_top_k_values_tensor, cos_scores_top_k_idx_tensor = (
                    torch.topk(
                        torch.tensor(similarity_scores),
                        1,
                        dim=1,
                        largest=True,
                        sorted=False,
                    )
                )
                cos_scores_top_k_values = cos_scores_top_k_values_tensor.cpu().tolist()
                cos_scores_top_k_idx = cos_scores_top_k_idx_tensor.cpu().tolist()

                for query_itr in range(len(similarity_scores)):
                    for sub_corpus_id, score in zip(
                        cos_scores_top_k_idx[query_itr],
                        cos_scores_top_k_values[query_itr],
                    ):
                        corpus_id = corpus_start_idx + sub_corpus_id
                        query_id = query_start_idx + query_itr
                        queries_result_list[query_id].append(
                            {"corpus_id": corpus_id, "score": score}
                        )

        result_queries_list: list[dict[str, float]] = [
            {} for _ in range(len(query_embeddings))
        ]
        # Sort and strip to top_k results
        for idx in range(len(queries_result_list)):
            queries_result_list[idx] = sorted(
                queries_result_list[idx], key=lambda x: x["score"], reverse=True
            )
            result_queries_list[idx] = queries_result_list[idx][0]

        return result_queries_list



from mteb.abstasks.image.image_text_pair_classification import (
    AbsTaskImageTextPairClassification,
)
from mteb.abstasks.task_metadata import TaskMetadata


class AROVisualRelation(AbsTaskImageTextPairClassification):
    images_column_names = ("image",)
    texts_column_names = ("true_caption", "false_caption")

    metadata = TaskMetadata(
        name="AROVisualRelation",
        description="Compositionality Evaluation of images to their captions.",
        reference="https://openreview.net/forum?id=KRLUvxh8uaX",
        dataset={
            "path": "mteb/ARO-Visual-Relation",
            "revision": "53c1115ab5871ab33b09d5bb8856236d46bdaf2d",
        },
        type="Compositionality",
        category="i2t",
        eval_splits=["test"],
        eval_langs=["eng-Latn"],
        main_score="text_acc",
        date=(
            "2022-01-01",
            "2022-12-31",
        ),  # Estimated range for the collection of data
        domains=["Encyclopaedic"],
        task_subtypes=["Caption Pairing"],
        license="mit",
        annotations_creators="expert-annotated",
        dialect=[],
        modalities=["text", "image"],
        sample_creation="created",
        bibtex_citation=r"""
@inproceedings{yuksekgonul2023and,
  author = {Yuksekgonul, Mert and Bianchi, Federico and Kalluri, Pratyusha and Jurafsky, Dan and Zou, James},
  booktitle = {The Eleventh International Conference on Learning Representations},
  title = {When and why vision-language models behave like bags-of-words, and what to do about it?},
  year = {2023},
}
""",
    )



from mteb.abstasks.retrieval import AbsTaskRetrieval
from mteb.abstasks.task_metadata import TaskMetadata


class HellaSwag(AbsTaskRetrieval):
    metadata = TaskMetadata(
        name="HellaSwag",
        description="Measuring the ability to retrieve the groundtruth answers to reasoning task queries on HellaSwag.",
        reference="https://rowanzellers.com/hellaswag/",
        dataset={
            "path": "mteb/HellaSwag",
            "revision": "944be88c186b87495f4b1f5e4a416a3a7ea5d680",
        },
        type="Retrieval",
        category="t2t",
        modalities=["text"],
        eval_splits=["test"],
        eval_langs=["eng-Latn"],
        main_score="ndcg_at_10",
        date=("2019-01-01", "2019-12-31"),
        domains=["Encyclopaedic", "Written"],
        task_subtypes=["Reasoning as Retrieval"],
        license="mit",
        annotations_creators="derived",
        dialect=[],
        sample_creation="found",
        bibtex_citation=r"""
@article{xiao2024rar,
  author = {Xiao, Chenghao and Hudson, G Thomas and Moubayed, Noura Al},
  journal = {arXiv preprint arXiv:2404.06347},
  title = {RAR-b: Reasoning as Retrieval Benchmark},
  year = {2024},
}

@article{zellers2019hellaswag,
  author = {Zellers, Rowan and Holtzman, Ari and Bisk, Yonatan and Farhadi, Ali and Choi, Yejin},
  journal = {arXiv preprint arXiv:1905.07830},
  title = {Hellaswag: Can a machine really finish your sentence?},
  year = {2019},
}
""",
        prompt={
            "query": "Given the following unfinished context, retrieve the most plausible ending to finish it."
        },
    )



from mteb.abstasks.classification import AbsTaskClassification
from mteb.abstasks.task_metadata import TaskMetadata


class VaccinChatNLClassification(AbsTaskClassification):
    metadata = TaskMetadata(
        name="VaccinChatNLClassification",
        description="VaccinChatNL is a Flemish Dutch FAQ dataset on the topic of COVID-19 vaccinations in Flanders.",
        reference="https://huggingface.co/datasets/clips/VaccinChatNL",
        dataset={
            "path": "clips/VaccinChatNL",
            "revision": "bd27d0058bea2ad52470d9072a3b5da6b97c1ac3",
        },
        type="Classification",
        category="t2c",
        modalities=["text"],
        date=("2022-01-01", "2022-09-01"),
        eval_splits=["test"],
        eval_langs=["nld-Latn"],
        main_score="f1",
        domains=["Spoken", "Web"],
        task_subtypes=[],
        license="cc-by-4.0",
        annotations_creators="expert-annotated",
        dialect=[],
        sample_creation="created",
        bibtex_citation=r"""
@inproceedings{buhmann-etal-2022-domain,
  address = {Gyeongju, Republic of Korea},
  author = {Buhmann, Jeska and De Bruyn, Maxime and Lotfi, Ehsan and Daelemans, Walter},
  booktitle = {Proceedings of the 29th International Conference on Computational Linguistics},
  month = oct,
  pages = {3539--3549},
  publisher = {International Committee on Computational Linguistics},
  title = {Domain- and Task-Adaptation for {V}accin{C}hat{NL}, a {D}utch {COVID}-19 {FAQ} Answering Corpus and Classification Model},
  url = {https://aclanthology.org/2022.coling-1.312},
  year = {2022},
}
""",
        prompt="Gegeven een gebruikersuiting als query, bepaal de gebruikersintenties",
    )

    def dataset_transform(
        self,
        num_proc: int | None = None,
    ):
        for split in self.dataset:
            self.dataset[split] = self.dataset[split].rename_columns(
                {"sentence1": "text"}
            )



from mteb.abstasks.classification import AbsTaskClassification
from mteb.abstasks.task_metadata import TaskMetadata


class TUTAcousticScenesClassification(AbsTaskClassification):
    metadata = TaskMetadata(
        name="TUTAcousticScenes",
        description="TUT Urban Acoustic Scenes 2018 dataset consists of 10-second audio segments from 10 acoustic scenes recorded in six European cities. This is a stratified subsampled version of the original dataset.",
        reference="https://zenodo.org/record/1228142",
        dataset={
            "path": "mteb/tut-acoustic-scenes-mini",
            "revision": "fe74de34b726995a39971faeb83491480ca1886e",
        },
        type="AudioClassification",
        category="a2c",
        eval_splits=["train"],
        eval_langs=["zxx-Zxxx"],
        main_score="accuracy",
        date=("2018-01-01", "2018-12-31"),
        domains=[
            "AudioScene",
        ],
        task_subtypes=["Environment Sound Classification"],
        license="cc-by-4.0",
        annotations_creators="expert-annotated",
        dialect=[],
        modalities=["audio"],
        sample_creation="found",
        bibtex_citation=r"""
@inproceedings{Mesaros2018_DCASE,
  address = {Tampere, Finland},
  author = {Annamaria Mesaros and Toni Heittola and Tuomas Virtanen},
  booktitle = {Proceedings of the Detection and Classification of Acoustic Scenes and Events 2018 Workshop (DCASE2018)},
  publisher = {Tampere University of Technology},
  title = {A Multi-Device Dataset for Urban Acoustic Scene Classification},
  url = {https://arxiv.org/abs/1807.09840},
  year = {2018},
}
""",
    )

    input_column_name: str = "audio"
    label_column_name: str = "scene_label"

    is_cross_validation: bool = True
    n_splits: int = 5



from mteb.abstasks.retrieval import AbsTaskRetrieval
from mteb.abstasks.task_metadata import TaskMetadata

_quora_metadata = dict(
    reference="https://quoradata.quora.com/First-Quora-Dataset-Release-Question-Pairs",
    type="Retrieval",
    category="t2t",
    modalities=["text"],
    eval_splits=["test"],
    eval_langs=["eng-Latn"],
    main_score="ndcg_at_10",
    date=("2017-01-01", "2017-12-31"),  # original publication year
    domains=["Written", "Web", "Blog"],
    task_subtypes=["Question answering"],
    license="not specified",
    annotations_creators="human-annotated",
    dialect=[],
    sample_creation="found",
    bibtex_citation=r"""
@misc{quora-question-pairs,
  author = {DataCanary, hilfialkaff, Lili Jiang, Meg Risdal, Nikhil Dandekar, tomtung},
  publisher = {Kaggle},
  title = {Quora Question Pairs},
  url = {https://kaggle.com/competitions/quora-question-pairs},
  year = {2017},
}
""",
)


class QuoraRetrieval(AbsTaskRetrieval):
    ignore_identical_ids = True

    metadata = TaskMetadata(
        name="QuoraRetrieval",
        dataset={
            "path": "mteb/quora",
            "revision": "e4e08e0b7dbe3c8700f0daef558ff32256715259",
        },
        description=(
            "QuoraRetrieval is based on questions that are marked as duplicates on the Quora platform. Given a"
            + " question, find other (duplicate) questions."
        ),
        prompt={
            "query": "Given a question, retrieve questions that are semantically equivalent to the given question"
        },
        **_quora_metadata,
    )


class QuoraRetrievalHardNegatives(AbsTaskRetrieval):
    ignore_identical_ids = True

    metadata = TaskMetadata(
        name="QuoraRetrievalHardNegatives",
        dataset={
            "path": "mteb/QuoraRetrieval_test_top_250_only_w_correct-v2",
            "revision": "907a33577e9506221d3ba20f5a851b7c3f8dc6d3",
        },
        description=(
            "QuoraRetrieval is based on questions that are marked as duplicates on the Quora platform. Given a"
            + " question, find other (duplicate) questions. The hard negative version has been created by pooling the 250 top documents per query from BM25, e5-multilingual-large and e5-mistral-instruct."
        ),
        adapted_from=["QuoraRetrieval"],
        superseded_by="QuoraRetrievalHardNegatives.v2",
        **_quora_metadata,
    )


class QuoraRetrievalHardNegativesV2(AbsTaskRetrieval):
    ignore_identical_ids = True

    metadata = TaskMetadata(
        name="QuoraRetrievalHardNegatives.v2",
        dataset={
            "path": "mteb/QuoraRetrieval_test_top_250_only_w_correct-v2",
            "revision": "907a33577e9506221d3ba20f5a851b7c3f8dc6d3",
        },
        description=(
            "QuoraRetrieval is based on questions that are marked as duplicates on the Quora platform. Given a "
            "question, find other (duplicate) questions. The hard negative version has been created by pooling the 250 top documents per query from BM25, e5-multilingual-large and e5-mistral-instruct."
            "V2 uses a more appropriate prompt rather than the default prompt for retrieval. You can get more information on the effect of different prompt in the [PR](https://github.com/embeddings-benchmark/mteb/pull/3469#issuecomment-3436467106)"
        ),
        adapted_from=["QuoraRetrieval"],
        prompt={
            "query": "Given a question, retrieve questions that are semantically equivalent to the given question"
        },
        **_quora_metadata,
    )



from __future__ import annotations

import json
import logging
from pathlib import Path
from typing import TYPE_CHECKING, Any

from huggingface_hub import (
    hf_hub_download,
    list_repo_commits,
    repo_exists,
)
from huggingface_hub.errors import (
    EntryNotFoundError,
    GatedRepoError,
    HFValidationError,
    RepositoryNotFoundError,
)

if TYPE_CHECKING:
    from huggingface_hub import GitCommitInfo

logger = logging.getLogger(__name__)


def _get_repo_commits(repo_id: str, repo_type: str) -> list[GitCommitInfo] | None:
    try:
        return list_repo_commits(repo_id=repo_id, repo_type=repo_type)
    except (GatedRepoError, RepositoryNotFoundError) as e:
        logger.warning(f"Can't get commits of {repo_id}: {e}")
        return None


def _get_json_from_hub(
    repo_id: str, file_name: str, repo_type: str, revision: str | None = None
) -> dict[str, Any] | None:
    path = _get_file_on_hub(repo_id, file_name, repo_type, revision)
    if path is None:
        return None

    with Path(path).open() as f:
        js = json.load(f)
    return js


def _get_file_on_hub(
    repo_id: str, file_name: str, repo_type: str, revision: str | None = None
) -> str | None:
    try:
        return hf_hub_download(
            repo_id=repo_id, filename=file_name, repo_type=repo_type, revision=revision
        )
    except (GatedRepoError, RepositoryNotFoundError, EntryNotFoundError) as e:
        logger.warning(f"Can't get file {file_name} of {repo_id}: {e}")
        return None


def _repo_exists(repo_id: str, repo_type: str | None = None) -> bool:
    """Checks if a repository exists on HuggingFace Hub.

    Repo exists will raise HFValidationError for invalid local paths

    Args:
        repo_id: The repository ID.
        repo_type: The type of repository (e.g., "model", "dataset", "space").
    """
    try:
        return repo_exists(repo_id=repo_id, repo_type=repo_type)
    except HFValidationError as e:
        logger.warning(f"Can't check existence of {repo_id}: {e}")
        return False



from mteb.abstasks.classification import AbsTaskClassification
from mteb.abstasks.task_metadata import TaskMetadata


class WikipediaIsotopesFissionClassification(AbsTaskClassification):
    metadata = TaskMetadata(
        name="WikipediaIsotopesFissionClassification",
        description="ChemTEB evaluates the performance of text embedding models on chemical domain data.",
        reference="https://arxiv.org/abs/2412.00532",
        dataset={
            "path": "BASF-AI/WikipediaHard2IsotopesVsFissionProductsNuclearFissionClassification",
            "revision": "897743346c7c794264f7dbfadc3978aa2895e8e2",
        },
        type="Classification",
        category="t2c",
        modalities=["text"],
        eval_splits=["test"],
        eval_langs=["eng-Latn"],
        main_score="accuracy",
        date=("2024-06-01", "2024-11-30"),
        domains=["Chemistry"],
        task_subtypes=[],
        license="cc-by-nc-sa-4.0",
        annotations_creators="derived",
        dialect=[],
        sample_creation="created",
        bibtex_citation=r"""
@article{kasmaee2024chemteb,
  author = {Kasmaee, Ali Shiraee and Khodadad, Mohammad and Saloot, Mohammad Arshi and Sherck, Nick and Dokas, Stephen and Mahyar, Hamidreza and Samiee, Soheila},
  journal = {arXiv preprint arXiv:2412.00532},
  title = {ChemTEB: Chemical Text Embedding Benchmark, an Overview of Embedding Models Performance \& Efficiency on a Specific Domain},
  year = {2024},
}
""",
    )



from .indic_xnli_pair_classification import IndicXnliPairClassification
from .opusparcus_pc import OpusparcusPC
from .paws_x_pair_classification import PawsXPairClassification
from .pub_chem_wiki_pair_classification import PubChemWikiPairClassification
from .rte3 import RTE3
from .x_stance import XStance
from .xnli import XNLI, XNLIV2

__all__ = [
    "RTE3",
    "XNLI",
    "XNLIV2",
    "IndicXnliPairClassification",
    "OpusparcusPC",
    "PawsXPairClassification",
    "PubChemWikiPairClassification",
    "XStance",
]



from mteb.abstasks.retrieval import AbsTaskRetrieval
from mteb.abstasks.task_metadata import TaskMetadata


class SWEbenchVerifiedReranking(AbsTaskRetrieval):
    metadata = TaskMetadata(
        name="SWEbenchVerifiedRR",
        description="Software Issue Localization for SWE-bench Verified",
        reference="https://openai.com/index/introducing-swe-bench-verified/",
        dataset={
            "path": "mteb/SWEbenchVerifiedRR",
            "revision": "373818dbe743204d007c3c27ca091a3349331afa",
        },
        type="Reranking",
        category="t2t",
        modalities=["text"],
        eval_splits=["train"],
        eval_langs=["eng-Latn", "python-Code"],
        main_score="recall_at_10",
        date=("2024-08-13", "2024-08-13"),  # arxiv v1 submission date
        domains=["Programming", "Written"],
        task_subtypes=["Code retrieval"],
        license="mit",
        annotations_creators="derived",
        dialect=[],
        sample_creation="found",
        prompt={
            "query": "Given a github issue, identify the code that needs to be changed to fix the issue."
        },
        bibtex_citation=r"""
@misc{openai2024swebenchverified,
  author = {OpenAI},
  title = {Introducing swe-bench verified},
  url = {https://openai.com/index/introducing-swe-bench-verified/},
  year = {2024},
}
""",
    )
